summaryrefslogtreecommitdiff
path: root/xmake/core/base/option.lua
diff options
context:
space:
mode:
authorOpportunity <[email protected]>2019-12-03 14:38:33 +0800
committerOpportunity <[email protected]>2019-12-03 14:38:33 +0800
commit54ba9a0faf46957c3da37366119e0dab52fc02cc (patch)
tree623d10f0ff8c6e94dcdd32b27dadce12ca31520a /xmake/core/base/option.lua
parent1db0db6a90a231423e03c79d0f09b7bdd4bd7099 (diff)
fix typo
Diffstat (limited to 'xmake/core/base/option.lua')
-rw-r--r--xmake/core/base/option.lua4
1 files changed, 2 insertions, 2 deletions
diff --git a/xmake/core/base/option.lua b/xmake/core/base/option.lua
index 1aa4a825c..029a252af 100644
--- a/xmake/core/base/option.lua
+++ b/xmake/core/base/option.lua
@@ -803,8 +803,8 @@ end
-- show update tips
function option.show_update_tips()
- -- show lastest version
- local versionfile = path.join(os.tmpdir(), "lastest_version")
+ -- show latest version
+ local versionfile = path.join(os.tmpdir(), "latest_version")
if os.isfile(versionfile) then
local versioninfo = io.load(versionfile)
if versioninfo and versioninfo.version and semver.compare(versioninfo.version, xmake._VERSION_SHORT) > 0 then